@@ -16,7 +16,7 @@ use Try::Tiny;
 
 use Moo;
 
-our $VERSION = '0.74';
+our $VERSION = '0.75';
 
 has conf_name => (
     is  => 'ro',
@@ -76,12 +76,28 @@ sub check {
             #
             # If there's nothing to stash there's no stash entry, in which
             # case popping would be very bad.
-            my $output = capturex(
+            my $pre_stash_state
+                = capturex( [ 0, 1 ], $self->git_path, qw( rev-parse -q --verify refs/stash ) );
+            run(
                 $self->git_path, qw( stash save --keep-index --include-untracked ),
                 'TidyAll pre-commit guard'
             );
-            $guard = guard { run( $self->git_path, 'stash', 'pop', '-q' ) }
-            unless $output =~ /No local changes/;
+            my $post_stash_state
+                = capturex( [ 0, 1 ], $self->git_path, qw( rev-parse -q --verify refs/stash ) );
+            unless ( $pre_stash_state eq $post_stash_state ) {
+                $guard = guard {
+                    my ($version) = capturex(qw( git version )) =~ /([0-9]+\.[0-9]+\.[0-9]+)/
+                        or die 'Cannot determine version number from git version output!';
+                    my $minor = ( split /\./, $version )[1];
+
+                    # When pop is run quietly in 2.24.x it deletes files! I can
+                    # make this guard smarter once there's a fixed version. See
+                    # https://public-inbox.org/git/CAMcnqp22tEFva4vYHYLzY83JqDHGzDbDGoUod21Dhtnvv=h_Pg@mail.gmail.com/
+                    # for the initial bug report.
+                    my @args = $minor >= 24 ? () : ('-q');
+                    run( $self->git_path, 'stash', 'pop', @args );
+                }
+            }
         }
 
         # Gather file paths to be committed
@@ -128,7 +144,7 @@ tidyall'd
 
 =head1 VERSION
 
-version 0.74
+version 0.75
 
 =head1 SYNOPSIS
 
