@@ -38,15 +38,15 @@ sub test_git : Tests {
     subtest 'attempt to commit untidy file', sub {
         my $output = capture_stderr { system(qw( git commit -q -m changed -a )) };
         like( $output, qr/1 file did not pass tidyall check/, '1 file did not pass tidyall check' );
-        like( $output, qr/needs tidying/, 'needs tidying' );
-        $self->_assert_something_to_commit;
+        like( $output, qr/needs tidying/,                     'needs tidying' );
+        $self->_assert_something_to_commit($work_dir);
     };
 
     subtest 'successfully commit tidied file', sub {
         $work_dir->child('foo.txt')->spew("ABC\n");
         my $output = capture_stderr { runx(qw( git commit -q -m changed -a )) };
         like( $output, qr/\[checked\] foo\.txt/, 'checked foo.txt' );
-        $self->_assert_nothing_to_commit;
+        $self->_assert_nothing_to_commit($work_dir);
     };
 
     subtest 'add another file which is tidied', sub {
@@ -71,7 +71,7 @@ sub test_git : Tests {
         runx( qw( git clone -q --bare ), map { _quote_for_win32($_) } $work_dir,   $shared_dir );
         runx( qw( git clone -q ),        map { _quote_for_win32($_) } $shared_dir, $clone_dir );
         chdir($clone_dir);
-        $self->_assert_nothing_to_commit;
+        $self->_assert_nothing_to_commit($work_dir);
     };
 
     my $prereceive_hook_file = $shared_dir->child(qw( hooks pre-receive ));
@@ -82,7 +82,7 @@ sub test_git : Tests {
     subtest 'untidy file and attempt to commit it via commit -a', sub {
         $clone_dir->child('foo.txt')->spew("def\n");
         runx(qw( git commit -q -m changed -a ));
-        $self->_assert_nothing_to_commit;
+        $self->_assert_nothing_to_commit($work_dir);
         $self->_assert_branch_is_ahead_of_origin;
     };
 
@@ -97,7 +97,7 @@ sub test_git : Tests {
     subtest 'can push tidied file', sub {
         $clone_dir->child('foo.txt')->spew("DEF\n");
         capture_stderr { runx(qw( git commit -q -m changed -a )) };
-        $self->_assert_nothing_to_commit;
+        $self->_assert_nothing_to_commit($work_dir);
         my $output = capture_stderr { system(qw( git push )) };
         like( $output, qr/master -> master/, 'push succeeded' );
         $self->_assert_nothing_to_push;
@@ -106,7 +106,7 @@ sub test_git : Tests {
     subtest 'untidy file and commit it', sub {
         $clone_dir->child('foo.txt')->spew("def\n");
         runx(qw( git commit -q -m changed -a ));
-        $self->_assert_nothing_to_commit;
+        $self->_assert_nothing_to_commit($work_dir);
         $self->_assert_branch_is_ahead_of_origin;
     };
 
@@ -120,7 +120,7 @@ sub test_git : Tests {
     subtest 'cannot push when file is untidy (2nd try)', sub {
         $self->_assert_branch_is_ahead_of_origin;
         my $output = capture_stderr { system(qw( git push )) };
-        like( $output, qr/needs tidying/, 'needs tidying' );
+        like( $output, qr/needs tidying/,               'needs tidying' );
         like( $output, qr/Identical push seen 2 times/, 'Identical push seen 2 times' );
         $self->_assert_branch_is_ahead_of_origin;
     };
@@ -128,9 +128,9 @@ sub test_git : Tests {
 
 sub _quote_for_win32 {
 
-    # The docs for IPC::System::Simple lie about how iallt works on
-    # Windows. On Windows it _always_ invokes a shell, so we need to quote a
-    # path with spaces.
+    # The docs for IPC::System::Simple lie about how it works on Windows. On
+    # Windows it _always_ invokes a shell, so we need to quote a path with
+    # spaces.
     return $_[0] unless IS_WIN32 && $_[0] =~ / /;
     return qq{"$_[0]"};
 }
@@ -174,26 +174,26 @@ sub test_precommit_stash_issues : Tests {
     $bar_file->spew("DEF\n");
 
     subtest 'commit two tidy files', sub {
-        $self->_assert_something_to_commit;
+        $self->_assert_something_to_commit($work_dir);
         runx(qw( git add foo.txt bar.txt ));
         my $output = capture_stderr( sub { runx(qw( git commit -q -m two )) } );
         like( $output, qr/\Q[checked] foo.txt/, 'tidyall checked foo.txt' );
         like( $output, qr/\Q[checked] bar.txt/, 'tidyall checked bar.txt' );
-        $self->_assert_nothing_to_commit;
+        $self->_assert_nothing_to_commit($work_dir);
     };
 
     $foo_file->spew("abc\n");
     $bar_file->spew("abc\n");
 
     subtest 'cannot commit untidy files', sub {
-        $self->_assert_something_to_commit;
+        $self->_assert_something_to_commit($work_dir);
         my $output = capture_stderr( sub { system(qw( git commit -q -a -m untidy )) } );
         like(
             $output,
             qr/2 files did not pass tidyall check/,
             'commit failed because 2 files are untidy'
         );
-        $self->_assert_something_to_commit;
+        $self->_assert_something_to_commit($work_dir);
     };
 
     $foo_file->spew("ABC\n");
@@ -289,11 +289,14 @@ sub _make_working_dir_and_repo {
 
     runx( qw( git init -q ), _quote_for_win32($work_dir) );
 
+    # This dir doesn't exist unless there's a git dir template that includes
+    # the hooks subdir.
+    $hooks_dir->mkpath( 0, 0755 );
     ok( -d $_, "$_ exists" ) for ( $work_dir, $hooks_dir );
 
     my $pushd = pushd($work_dir);
 
-    $work_dir->child('tidyall.ini')->spew( sprintf($tidyall_ini_template) );
+    $work_dir->child('tidyall.ini')->spew($tidyall_ini_template);
     $work_dir->child('.gitignore')->spew('.tidyall.d');
     runx(qw( git add tidyall.ini .gitignore ));
     runx(qw( git commit -q -m added tidyall.ini .gitignore ));
@@ -311,11 +314,16 @@ sub _lib_dirs {
 }
 
 sub _assert_nothing_to_commit {
-    like( capturex( 'git', 'status' ), qr/nothing to commit/, 'nothing to commit' );
+    shift;
+    my @files = git_files_to_commit(shift);
+    is( scalar @files, 0, 'there are no files to commit' )
+        or diag("@files");
 }
 
 sub _assert_something_to_commit {
-    unlike( capturex( 'git', 'status' ), qr/nothing to commit/, 'something to commit' );
+    shift;
+    my @files = git_files_to_commit(shift);
+    cmp_ok( scalar @files, '>=', 0, 'there are files to commit' );
 }
 
 sub _assert_nothing_to_push {
