@@ -20,8 +20,8 @@ sub startup : Tests(startup => no_plan) {
 
     $self->{root_dir} = tempdir_simple();
 
-    my $extra = $self->_extra_path();
-    $ENV{PATH} .= q{:} . $extra if $extra;
+    my @extra = $self->_extra_path();
+    $ENV{PATH} .= q{:} . join ':', @extra if @extra;
 
     return;
 }
@@ -37,12 +37,10 @@ sub test_filename {'foo.txt'}
 sub tidyall {
     my ( $self, %p ) = @_;
 
-    my $plugin_class = $self->plugin_class;
-    my %plugin_conf  = ( $plugin_class => { select => '*', %{ $p{conf} || {} } } );
-    my $ct           = Code::TidyAll->new(
+    my $ct = Code::TidyAll->new(
         quiet    => 1,
         root_dir => $self->{root_dir},
-        plugins  => \%plugin_conf,
+        plugins  => ( $p{plugin_conf} ? $p{plugin_conf} : $self->_plugin_conf( $p{conf} ) ),
     );
 
     my ( $source, $result, $output, $error );
@@ -89,8 +87,30 @@ sub tidyall {
     }
 }
 
+sub _plugin_conf {
+    my $self = shift;
+    my $conf = shift;
+
+    my $plugin_class = $self->plugin_class;
+    return { $plugin_class => { select => '*', %{ $conf || {} } } };
+}
+
 sub _extra_path {
     return;
 }
 
+{
+    my $Perl = $^X;
+    if ( $^O eq 'MSWin32' ) {
+
+        # We need to use forward slashes to get this working with all the
+        # layers of quoting in RunsCommand and IPC::Run3.
+        $Perl =~ s{\\}{/}g;
+    }
+
+    sub _this_perl {
+        return $Perl;
+    }
+}
+
 1;
